summaryrefslogtreecommitdiff
path: root/shell/source/unix
diff options
context:
space:
mode:
authorStephan Bergmann <sbergman@redhat.com>2011-10-06 21:29:44 +0200
committerStephan Bergmann <sbergman@redhat.com>2011-10-06 22:36:31 +0200
commitd550bc3f450dd2d3aa33398eb31bc1163a181c43 (patch)
treebf202fe182a72bb88600a71a6f82ae4ee1212cc0 /shell/source/unix
parent243ead838369b030579f501ce1f77689ce822f06 (diff)
Undo basis/brand split: move some auxiliary executables from basis to brand.
Diffstat (limited to 'shell/source/unix')
-rw-r--r--shell/source/unix/exec/shellexec.cxx6
-rw-r--r--shell/source/unix/misc/makefile.mk2
2 files changed, 5 insertions, 3 deletions
diff --git a/shell/source/unix/misc/makefile.mk b/shell/source/unix/misc/makefile.mk
index be4660db3e8c..3f1b64e652e0 100644
--- a/shell/source/unix/misc/makefile.mk
+++ b/shell/source/unix/misc/makefile.mk
@@ -51,6 +51,7 @@ APP1TARGET = gnome-open-url.bin
APP1OBJS = \
$(OBJ)$/gnome-open-url.obj
APP1LIBS =
+APP1RPATH = BRAND
.IF "$(OS)"!="FREEBSD" && "$(OS)"!="NETBSD" && "$(OS)"!="OPENBSD" && \
"$(OS)"!="DRAGONFLY"
APP1STDLIBS=-ldl
@@ -59,6 +60,7 @@ APP1STDLIBS=-ldl
APP2TARGET = uri-encode
APP2OBJS = $(OBJ)$/uri-encode.obj
APP2LIBS =
+APP2RPATH = BRAND
APP2STDLIBS =
OBJFILES = $(APP1OBJS) $(APP2OBJS)
diff --git a/shell/source/unix/exec/shellexec.cxx b/shell/source/unix/exec/shellexec.cxx
index 4af7c7bfff84..40a2fa3f9b13 100644
--- a/shell/source/unix/exec/shellexec.cxx
+++ b/shell/source/unix/exec/shellexec.cxx
@@ -159,7 +159,7 @@ void SAL_CALL ShellExec::execute( const OUString& aCommand, const OUString& aPar
#ifdef MACOSX
aBuffer.append("open");
#else
// The url launchers are expected to be in the $OOO_BASE_DIR/program
// directory:
com::sun::star::uno::Reference< com::sun::star::util::XMacroExpander >
exp;
@@ -182,11 +182,11 @@ void SAL_CALL ShellExec::execute( const OUString& aCommand, const OUString& aPar
try {
aProgramURL = exp->expandMacros(
rtl::OUString(
- RTL_CONSTASCII_USTRINGPARAM("$OOO_BASE_DIR/program/")));
+ RTL_CONSTASCII_USTRINGPARAM("$BRAND_BASE_DIR/program/")));
} catch (com::sun::star::lang::IllegalArgumentException &)
{
throw SystemShellExecuteException(
- OUString(RTL_CONSTASCII_USTRINGPARAM("Could not expand $OOO_BASE_DIR path")),
+ OUString(RTL_CONSTASCII_USTRINGPARAM("Could not expand $BRAND_BASE_DIR path")),
static_cast < XSystemShellExecute * > (this), ENOENT );
}
@@ -159,7 +159,7 @@ void SAL_CALL ShellExec::execute( const OUString& aCommand, const OUString& aPar
aBuffer.append("open");
#else
- // The url launchers are expected to be in the $OOO_BASE_DIR/program
+ // The url launchers are expected to be in the $BRAND_BASE_DIR/program
// directory:
com::sun::star::uno::Reference< com::sun::star::util::XMacroExpander >